BIDSO
=====
Transparent Object-Oriented Approach to BIDS in Python.

Features
--------

- Pure Python

Installation
------------
Install won by running:

    pip install bidso

Requirements
------------
- Python 3.6
- nibabel


Status
------
.. image:: https://travis-ci.org/gpiantoni/bidso.svg?branch=master
    :target: https://travis-ci.org/gpiantoni/bidso

.. image:: https://codecov.io/gh/gpiantoni/bidso/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/gpiantoni/bidso

License
-------
The project is licensed under the MIT license.
